message

Macro message 

message!() { /* proc-macro */ }
Writes an informational message via the Output on Context

Expands to context.output().message(format!(...)).await.expect("event channel closed"), where context resolves to the local variable in the calling function’s scope. This is the macro equivalent of Output::message.

The macro must be called from an async function because the core Output methods are async.

Examples

use clawless::prelude::*;

#[command]
pub async fn deploy(args: DeployArgs, context: Context) -> CommandResult {
    message!("deploying to {}", args.target);
    Ok(())
}